@@ -35,7 +35,7 @@ your system.
 
 use XSLoader;
 
-our $VERSION = '0.03_01';
+our $VERSION = '0.03_02';
 
 XSLoader::load( __PACKAGE__, $VERSION );
 
@@ -149,20 +149,18 @@ To counteract this loss of precision, add 0 to Perl’s numeric scalars
 numbers as integers when possible, which fixes the precision problem.
 
 =item * Long-double and quad-math perls may lose precision when converting
-numbers to/from JavaScript. To see if this is a problem for you, run
-C<perl -V>, and see if the compile-time options mention long doubles or
-quad math.
+numbers to/from JavaScript. To see if this affects your perl—which, if
+you’re unsure, it probably doesn’t—run C<perl -V>, and see if the
+compile-time options mention long doubles or quad math.
 
 =back
 
-=head1 PLATFORM NOTES
+=head1 OS SUPPORT
 
-Due to QuickJS limitations, Linux & macOS are the only platforms known
-to work “out-of-the-box”. Other POSIX OSes I<should> work with some small
-tweaks to quickjs; see the compiler errors and F<quickjs.c> for more
-details.
+QuickJS supports Linux & macOS natively, so these work without issue.
 
-Pull requests to improve portability are welcome!
+FreeBSD, OpenBSD, & Cygwin work after a few patches that we apply when
+building this library. (Hopefully these will eventually merge into QuickJS.)
 
 =head1 SEE ALSO
 
